@@ -80,7 +80,7 @@ public:
   /**
    * Sets/Gets the range of scalars that will be mapped.
    */
-  virtual double *GetRange();
+  virtual double *GetRange() VTK_SIZEHINT(2);
   virtual void SetRange(double min, double max);
   virtual void SetRange(const double rng[2])
     {this->SetRange(rng[0],rng[1]);}
@@ -90,7 +90,7 @@ public:
    * Map one value through the lookup table and return a color defined
    * as an RGBA unsigned char tuple (4 bytes).
    */
-  virtual unsigned char *MapValue(double v);
+  virtual const unsigned char *MapValue(double v);
 
   /**
    * Map one value through the lookup table and store the color as
@@ -102,7 +102,7 @@ public:
    * Map one value through the lookup table and return the color as
    * an RGB array of doubles between 0 and 1.
    */
-  double *GetColor(double v)
+  double *GetColor(double v) VTK_SIZEHINT(3)
     {this->GetColor(v,this->RGB); return this->RGB;}
 
   /**
@@ -331,7 +331,7 @@ public:
    * the annotations were set).
    * Subclasses must implement this and interpret how to treat the index.
    * vtkLookupTable simply returns GetTableValue(\a index % \a this->GetNumberOfTableValues()).
-   * vtkColorTransferFunction returns the color assocated with node \a index % \a this->GetSize().
+   * vtkColorTransferFunction returns the color associated with node \a index % \a this->GetSize().
 
    * Note that implementations *must* set the opacity (alpha) component of the color, even if they
    * do not provide opacity values in their colormaps. In that case, alpha = 1 should be used.
@@ -360,9 +360,9 @@ public:
    * When categorical data is present, only values in the lookup table will be
    * considered valid; all other values will be assigned \a NanColor.
    */
-  vtkSetMacro(IndexedLookup,int);
-  vtkGetMacro(IndexedLookup,int);
-  vtkBooleanMacro(IndexedLookup,int);
+  vtkSetMacro(IndexedLookup,vtkTypeBool);
+  vtkGetMacro(IndexedLookup,vtkTypeBool);
+  vtkBooleanMacro(IndexedLookup,vtkTypeBool);
   //@}
 
 
@@ -442,7 +442,7 @@ protected:
   class vtkInternalAnnotatedValueMap;
   vtkInternalAnnotatedValueMap* AnnotatedValueMap;
 
-  int IndexedLookup;
+  vtkTypeBool IndexedLookup;
 
   double Alpha;
 
