@@ -71,21 +71,29 @@ public class vtkCharArray extends vtkDataArray
   public String GetPointer(int id0)
     { return GetPointer_15(id0); }
 
-  private native long FastDownCast_16(vtkAbstractArray id0);
+  private native void SetArray_16(String id0,int id1,int id2);
+  public void SetArray(String id0,int id1,int id2)
+    { SetArray_16(id0,id1,id2); }
+
+  private native void SetArray_17(String id0,int id1,int id2,int id3);
+  public void SetArray(String id0,int id1,int id2,int id3)
+    { SetArray_17(id0,id1,id2,id3); }
+
+  private native long FastDownCast_18(vtkAbstractArray id0);
   public vtkCharArray FastDownCast(vtkAbstractArray id0) {
-    long temp = FastDownCast_16(id0);
+    long temp = FastDownCast_18(id0);
 
     if (temp == 0) return null;
     return (vtkCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native char GetDataTypeValueMin_17();
+  private native char GetDataTypeValueMin_19();
   public char GetDataTypeValueMin()
-    { return GetDataTypeValueMin_17(); }
+    { return GetDataTypeValueMin_19(); }
 
-  private native char GetDataTypeValueMax_18();
+  private native char GetDataTypeValueMax_20();
   public char GetDataTypeValueMax()
-    { return GetDataTypeValueMax_18(); }
+    { return GetDataTypeValueMax_20(); }
 
   private native char[] GetJavaArray_0();
   public char[] GetJavaArray()
