@@ -155,177 +155,193 @@ public class vtkGlyph3DMapper extends vtkMapper
   public void SetOrientationModeToRotation()
     { SetOrientationModeToRotation_34(); }
 
-  private native String GetOrientationModeAsString_35();
+  private native void SetOrientationModeToQuaternion_35();
+  public void SetOrientationModeToQuaternion()
+    { SetOrientationModeToQuaternion_35(); }
+
+  private native String GetOrientationModeAsString_36();
   public String GetOrientationModeAsString()
-    { return GetOrientationModeAsString_35(); }
+    { return GetOrientationModeAsString_36(); }
 
-  private native void SetClamping_36(boolean id0);
+  private native void SetClamping_37(boolean id0);
   public void SetClamping(boolean id0)
-    { SetClamping_36(id0); }
+    { SetClamping_37(id0); }
 
-  private native boolean GetClamping_37();
+  private native boolean GetClamping_38();
   public boolean GetClamping()
-    { return GetClamping_37(); }
+    { return GetClamping_38(); }
 
-  private native void ClampingOn_38();
+  private native void ClampingOn_39();
   public void ClampingOn()
-    { ClampingOn_38(); }
+    { ClampingOn_39(); }
 
-  private native void ClampingOff_39();
+  private native void ClampingOff_40();
   public void ClampingOff()
-    { ClampingOff_39(); }
+    { ClampingOff_40(); }
 
-  private native void SetSourceIndexing_40(boolean id0);
+  private native void SetSourceIndexing_41(boolean id0);
   public void SetSourceIndexing(boolean id0)
-    { SetSourceIndexing_40(id0); }
+    { SetSourceIndexing_41(id0); }
 
-  private native boolean GetSourceIndexing_41();
+  private native boolean GetSourceIndexing_42();
   public boolean GetSourceIndexing()
-    { return GetSourceIndexing_41(); }
+    { return GetSourceIndexing_42(); }
 
-  private native void SourceIndexingOn_42();
+  private native void SourceIndexingOn_43();
   public void SourceIndexingOn()
-    { SourceIndexingOn_42(); }
+    { SourceIndexingOn_43(); }
 
-  private native void SourceIndexingOff_43();
+  private native void SourceIndexingOff_44();
   public void SourceIndexingOff()
-    { SourceIndexingOff_43(); }
+    { SourceIndexingOff_44(); }
 
-  private native void SetUseSourceTableTree_44(boolean id0);
+  private native void SetUseSourceTableTree_45(boolean id0);
   public void SetUseSourceTableTree(boolean id0)
-    { SetUseSourceTableTree_44(id0); }
+    { SetUseSourceTableTree_45(id0); }
 
-  private native boolean GetUseSourceTableTree_45();
+  private native boolean GetUseSourceTableTree_46();
   public boolean GetUseSourceTableTree()
-    { return GetUseSourceTableTree_45(); }
+    { return GetUseSourceTableTree_46(); }
 
-  private native void UseSourceTableTreeOn_46();
+  private native void UseSourceTableTreeOn_47();
   public void UseSourceTableTreeOn()
-    { UseSourceTableTreeOn_46(); }
+    { UseSourceTableTreeOn_47(); }
 
-  private native void UseSourceTableTreeOff_47();
+  private native void UseSourceTableTreeOff_48();
   public void UseSourceTableTreeOff()
-    { UseSourceTableTreeOff_47(); }
+    { UseSourceTableTreeOff_48(); }
 
-  private native void SetUseSelectionIds_48(boolean id0);
+  private native void SetUseSelectionIds_49(boolean id0);
   public void SetUseSelectionIds(boolean id0)
-    { SetUseSelectionIds_48(id0); }
+    { SetUseSelectionIds_49(id0); }
 
-  private native void UseSelectionIdsOn_49();
+  private native void UseSelectionIdsOn_50();
   public void UseSelectionIdsOn()
-    { UseSelectionIdsOn_49(); }
+    { UseSelectionIdsOn_50(); }
 
-  private native void UseSelectionIdsOff_50();
+  private native void UseSelectionIdsOff_51();
   public void UseSelectionIdsOff()
-    { UseSelectionIdsOff_50(); }
+    { UseSelectionIdsOff_51(); }
 
-  private native boolean GetUseSelectionIds_51();
+  private native boolean GetUseSelectionIds_52();
   public boolean GetUseSelectionIds()
-    { return GetUseSelectionIds_51(); }
+    { return GetUseSelectionIds_52(); }
 
-  private native void GetBounds_52(double id0[]);
+  private native void GetBounds_53(double id0[]);
   public void GetBounds(double id0[])
-    { GetBounds_52(id0); }
+    { GetBounds_53(id0); }
 
-  private native void Render_53(vtkRenderer id0,vtkActor id1);
+  private native void Render_54(vtkRenderer id0,vtkActor id1);
   public void Render(vtkRenderer id0,vtkActor id1)
-    { Render_53(id0,id1); }
+    { Render_54(id0,id1); }
 
-  private native void SetNestedDisplayLists_54(boolean id0);
-  public void SetNestedDisplayLists(boolean id0)
-    { SetNestedDisplayLists_54(id0); }
-
-  private native boolean GetNestedDisplayLists_55();
-  public boolean GetNestedDisplayLists()
-    { return GetNestedDisplayLists_55(); }
-
-  private native void NestedDisplayListsOn_56();
-  public void NestedDisplayListsOn()
-    { NestedDisplayListsOn_56(); }
-
-  private native void NestedDisplayListsOff_57();
-  public void NestedDisplayListsOff()
-    { NestedDisplayListsOff_57(); }
-
-  private native void SetMasking_58(boolean id0);
+  private native void SetMasking_55(boolean id0);
   public void SetMasking(boolean id0)
-    { SetMasking_58(id0); }
+    { SetMasking_55(id0); }
 
-  private native boolean GetMasking_59();
+  private native boolean GetMasking_56();
   public boolean GetMasking()
-    { return GetMasking_59(); }
+    { return GetMasking_56(); }
 
-  private native void MaskingOn_60();
+  private native void MaskingOn_57();
   public void MaskingOn()
-    { MaskingOn_60(); }
+    { MaskingOn_57(); }
 
-  private native void MaskingOff_61();
+  private native void MaskingOff_58();
   public void MaskingOff()
-    { MaskingOff_61(); }
+    { MaskingOff_58(); }
 
-  private native void SetMaskArray_62(String id0);
+  private native void SetMaskArray_59(String id0);
   public void SetMaskArray(String id0)
-    { SetMaskArray_62(id0); }
+    { SetMaskArray_59(id0); }
 
-  private native void SetMaskArray_63(int id0);
+  private native void SetMaskArray_60(int id0);
   public void SetMaskArray(int id0)
-    { SetMaskArray_63(id0); }
+    { SetMaskArray_60(id0); }
 
-  private native void SetOrientationArray_64(String id0);
+  private native void SetOrientationArray_61(String id0);
   public void SetOrientationArray(String id0)
-    { SetOrientationArray_64(id0); }
+    { SetOrientationArray_61(id0); }
 
-  private native void SetOrientationArray_65(int id0);
+  private native void SetOrientationArray_62(int id0);
   public void SetOrientationArray(int id0)
-    { SetOrientationArray_65(id0); }
+    { SetOrientationArray_62(id0); }
 
-  private native void SetScaleArray_66(String id0);
+  private native void SetScaleArray_63(String id0);
   public void SetScaleArray(String id0)
-    { SetScaleArray_66(id0); }
+    { SetScaleArray_63(id0); }
 
-  private native void SetScaleArray_67(int id0);
+  private native void SetScaleArray_64(int id0);
   public void SetScaleArray(int id0)
-    { SetScaleArray_67(id0); }
+    { SetScaleArray_64(id0); }
 
-  private native void SetSourceIndexArray_68(String id0);
+  private native void SetSourceIndexArray_65(String id0);
   public void SetSourceIndexArray(String id0)
-    { SetSourceIndexArray_68(id0); }
+    { SetSourceIndexArray_65(id0); }
 
-  private native void SetSourceIndexArray_69(int id0);
+  private native void SetSourceIndexArray_66(int id0);
   public void SetSourceIndexArray(int id0)
-    { SetSourceIndexArray_69(id0); }
+    { SetSourceIndexArray_66(id0); }
 
-  private native void SetSelectionIdArray_70(String id0);
+  private native void SetSelectionIdArray_67(String id0);
   public void SetSelectionIdArray(String id0)
-    { SetSelectionIdArray_70(id0); }
+    { SetSelectionIdArray_67(id0); }
 
-  private native void SetSelectionIdArray_71(int id0);
+  private native void SetSelectionIdArray_68(int id0);
   public void SetSelectionIdArray(int id0)
-    { SetSelectionIdArray_71(id0); }
+    { SetSelectionIdArray_68(id0); }
 
-  private native void SetSelectionColorId_72(int id0);
+  private native void SetSelectionColorId_69(int id0);
   public void SetSelectionColorId(int id0)
-    { SetSelectionColorId_72(id0); }
+    { SetSelectionColorId_69(id0); }
 
-  private native int GetSelectionColorId_73();
+  private native int GetSelectionColorId_70();
   public int GetSelectionColorId()
-    { return GetSelectionColorId_73(); }
+    { return GetSelectionColorId_70(); }
 
-  private native void SetBlockAttributes_74(vtkCompositeDataDisplayAttributes id0);
+  private native void SetBlockAttributes_71(vtkCompositeDataDisplayAttributes id0);
   public void SetBlockAttributes(vtkCompositeDataDisplayAttributes id0)
-    { SetBlockAttributes_74(id0); }
+    { SetBlockAttributes_71(id0); }
 
-  private native long GetBlockAttributes_75();
+  private native long GetBlockAttributes_72();
   public vtkCompositeDataDisplayAttributes GetBlockAttributes() {
-    long temp = GetBlockAttributes_75();
+    long temp = GetBlockAttributes_72();
 
     if (temp == 0) return null;
     return (vtkCompositeDataDisplayAttributes)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native boolean GetSupportsSelection_76();
+  private native void SetCullingAndLOD_73(boolean id0);
+  public void SetCullingAndLOD(boolean id0)
+    { SetCullingAndLOD_73(id0); }
+
+  private native boolean GetCullingAndLOD_74();
+  public boolean GetCullingAndLOD()
+    { return GetCullingAndLOD_74(); }
+
+  private native int GetMaxNumberOfLOD_75();
+  public int GetMaxNumberOfLOD()
+    { return GetMaxNumberOfLOD_75(); }
+
+  private native void SetNumberOfLOD_76(int id0);
+  public void SetNumberOfLOD(int id0)
+    { SetNumberOfLOD_76(id0); }
+
+  private native void SetLODDistanceAndTargetReduction_77(int id0,double id1,double id2);
+  public void SetLODDistanceAndTargetReduction(int id0,double id1,double id2)
+    { SetLODDistanceAndTargetReduction_77(id0,id1,id2); }
+
+  private native void SetLODColoring_78(boolean id0);
+  public void SetLODColoring(boolean id0)
+    { SetLODColoring_78(id0); }
+
+  private native boolean GetLODColoring_79();
+  public boolean GetLODColoring()
+    { return GetLODColoring_79(); }
+
+  private native boolean GetSupportsSelection_80();
   public boolean GetSupportsSelection()
-    { return GetSupportsSelection_76(); }
+    { return GetSupportsSelection_80(); }
 
   public vtkGlyph3DMapper() { super(); }
 
